@@ -394,7 +394,7 @@ def registered_disk_actions(auto_action=None, owner='', **kwargs):
         elif action in ('9', 'eject'):
             break  # Quit + EJECT
 
-        elif action == 'D':
+        elif action in ('D', 'dispose'):
             assert location != 'remote', 'Cannot remote-dispose..'
             inventory_rest_client.add_status(
                 hdd_id, status='HDD_DISPOSED',
@@ -694,6 +694,10 @@ class AutoServer:
         self.owner = owner
         # Make sure the environment is valid to start osso-docktool.
         self.author, self.location = get_author_and_location()
+        # It's possible a device does not eject/spin down properly and triggers
+        # the udev rules again. Keep a list of disk serials which have been
+        # started and ignore subsequent notifications about that disk.
+        self.seen_devices = set()
         if not gui:
             if not os.environ.get('TMUX'):
                 args = [
@@ -720,6 +724,8 @@ class AutoServer:
             raise SystemExit()
 
     def listen(self):
+        if os.getuid() != 0:
+            warn('Expected UID 0 (root) for access')
         with socket(AF_INET, SOCK_STREAM) as sock:
             sock.bind(('127.0.0.1', 1451))
             sock.listen(4)
@@ -760,9 +766,16 @@ class AutoServer:
                 client_data += data
 
         if client_data:
-            device = Path(client_data.decode())
+            notification = client_data.decode()
+            try:
+                cmd, device = notification.split(':', 1)
+            except ValueError:
+                print(f'Received bogus notification: {notification!r}')
+                return
+
+            device = Path(device)
             if device.is_block_device():
-                if self.is_ignored(device):
+                if self.is_ignored(device, force=bool(cmd == 'device-force')):
                     print(f'Ignoring notification for {device}')
                 else:
                     self.start_docktool(device)
@@ -773,7 +786,15 @@ class AutoServer:
     def docktool_exec(self):
         return Path(sys.argv[0]).resolve()
 
-    def is_ignored(self, device):
+    def is_ignored(self, device, force):
+        hdd_dock = BaseStorageDevice.from_devname(device)
+        serial = hdd_dock.get_serial_number()
+        if not force and serial in self.seen_devices:
+            print(f'Device {device} with serial {serial} has been processed')
+            print(
+                f'Use "osso-docktool auto-notify {device} --force" to start')
+            return True
+        self.seen_devices.add(serial)
         # Check the resolved path against the ignore list.
         return bool(device.resolve() in self.ignore_devices)
 
@@ -813,11 +834,12 @@ class AutoServer:
         return cmd
 
 
-def auto_notify(device):
+def auto_notify(device, force=False):
+    notification = f'device-force:{device}' if force else f'device:{device}'
     with socket(AF_INET, SOCK_STREAM) as sock:
         try:
             sock.connect(('127.0.0.1', 1451))
-            sock.sendall(str(device).encode())
+            sock.sendall(notification.encode())
         except ConnectionError as e:
             print(f'Error notifying auto process: {e}', file=sys.stderr)
 
@@ -842,8 +864,8 @@ class DocktoolArgumentParser(argparse.ArgumentParser):
             help='Device to use for example: /dev/sda')
         devparser.add_argument(
             '-a', '--action', choices=[
-                'eject', 'print-label', 'print-health-label', 'locate',
-                'set-owner', 'quick-erase', 'secure-erase'],
+                'dispose', 'eject', 'print-label', 'print-health-label',
+                'locate', 'set-owner', 'quick-erase', 'secure-erase'],
             action='append', default=[],
             help='Automatically execute the actions in order.')
         devparser.add_argument(
@@ -879,14 +901,17 @@ class DocktoolArgumentParser(argparse.ArgumentParser):
             # https://bugs.python.org/issue27227
             # Add [] to choices to make actions optional.
             'action', nargs='*', choices=[
-                'eject', 'print-label', 'print-health-label', 'locate',
-                'set-owner', 'quick-erase', 'secure-erase', []],
+                'dispose', 'eject', 'print-label', 'print-health-label',
+                'locate', 'set-owner', 'quick-erase', 'secure-erase', []],
             help='Start docktool and perform these actions in order '
                  '(default: start osso-docktool, no extra action).')
 
         notifyparser = self.subparsers.add_parser(
             'auto-notify',
-            help='Notify the auto process of the device')
+            help='Notify the auto server of the device')
+        notifyparser.add_argument(
+            '-f', '--force', action='store_true',
+            help='Force the auto server to process the device.')
         notifyparser.add_argument(
             'device', metavar='DISK', type=self.block_device,
             help='Device to use for example: /dev/sda')
@@ -946,7 +971,7 @@ def main():
         elif args.command == 'auto':
             AutoServer(args.action, args.gui, args.ignore, args.owner).start()
         elif args.command == 'auto-notify':
-            auto_notify(args.device)
+            auto_notify(args.device, args.force)
     except KeyboardInterrupt:
         sys.exit(0)
     except SystemExit:
