@@ -112,7 +112,11 @@ class BaseStorageDevice(object):
         return port or self.devname
 
     def led(self, pattern='locate'):
-        subprocess.check_call(['ledctl', '-x', f'{pattern}={self.devname}'])
+        try:
+            subprocess.check_call([
+                'ledctl', '-x', f'{pattern}={self.devname}'])
+        except subprocess.CalledProcessError:
+            print(f'LED control failed to set pattern: {pattern}')
 
     def led_failure(self):
         self.led('failure')
@@ -383,6 +387,10 @@ class FallbackStorageDevice(GenericStorageDeviceBase):
             'NOTICE: Using secret {!r}.. you may need this to unbrick!'
             .format(secret))
 
+        # Log the secret+serial to the workdir.
+        with open('osso-docktool.log', 'a') as f:
+            f.write(f'{self.get_serial_number()}: Using secret {secret!r}')
+
         print('> --security-set-pass')
         subprocess.check_output([
             '/sbin/hdparm', '--user-master', 'u',
